@@ -37,41 +37,6 @@ impl From<Option<Vec<Node>>> for Node {
   }
 }
 
-impl ToString for Node {
-  fn to_string(&self) -> String {
-    match self {
-      Node::Comment(children) => children
-        .children
-        .iter()
-        .map(|n| n.to_string())
-        .collect::<Vec<_>>()
-        .join("\n"),
-      Node::CustomElement => todo!("CustomElement"),
-      Node::Document(doctype, children) => {
-        format!(
-          "{}{}",
-          doctype.to_string(),
-          children
-            .children
-            .iter()
-            .map(|n| n.to_string())
-            .collect::<Vec<_>>()
-            .join("\n")
-        )
-      }
-      Node::Element(el) => el.to_string(),
-      Node::Fragment(children) => children
-        .children
-        .iter()
-        .map(|n| n.to_string())
-        .collect::<Vec<_>>()
-        .join("\n"),
-      Node::None => String::new(),
-      Node::Text(text) => text.clone(),
-    }
-  }
-}
-
 macro_rules! impl_renderable {
   ($($t:ty),*) => {
     $(
@@ -86,6 +51,24 @@ macro_rules! impl_renderable {
           Node::Text(item.to_string())
         }
       }
+
+      impl From<Option<$t>> for Node {
+        fn from(item: Option<$t>) -> Node {
+          match item.as_ref() {
+            Some(item) => Node::Text(item.to_string()),
+            None => Node::None,
+          }
+        }
+      }
+
+      impl From<Option<& $t>> for Node {
+        fn from(item: Option<& $t>) -> Node {
+          match item {
+            Some(item) => Node::Text(item.to_string()),
+            None => Node::None,
+          }
+        }
+      }
     )*
   };
 }
