@@ -25,25 +25,24 @@ mod test {
   use crate::{
     html::{Element, Node},
     render::RenderString,
+    Children,
   };
 
   #[test]
   fn test_render_into() {
     let element = Element {
       name: "div",
-      attributes: vec![],
-      children: vec![
-        Node::Element(Element {
+      attributes: Default::default(),
+      children: Children::default()
+        .set(Node::Element(Element {
           name: "span",
-          attributes: vec![],
-          children: vec![
-            Node::Text("Hello".to_owned()),
-            Node::Text(" ".to_owned()),
-            Node::Text("1".to_owned()),
-          ],
-        }),
-        Node::Text(", World 2".to_owned()),
-      ],
+          attributes: Default::default(),
+          children: Children::default()
+            .set(Node::Text("Hello".to_owned()))
+            .set(Node::Text(" ".to_owned()))
+            .set(Node::Text("1".to_owned())),
+        }))
+        .set(Node::Text(", World 2".to_owned())),
     };
 
     assert_eq!(element.render(), "<div><span>Hello 1</span>, World 2</div>");
